@@ -12,14 +12,15 @@ class JSONSchemaOutput(JSONOutput):
         # just a sanity check
         if not isinstance(top, dict):
             return
-        if 'properties' not in top:
+        if "properties" not in top:
             return
         required = []
-        for prop_key, prop in top['properties'].items():
+        for prop_key, prop in top["properties"].items():
             if not isinstance(prop, dict):
                 continue
-            if prop.pop('required', None):
-                required.append(prop_key)
+            if not isinstance(prop.get("required"), list):
+                if prop.pop("required", None):
+                    required.append(prop_key)
         if required:
             required.sort()
-            top['required'] = required
+            top["required"] = required
